Module blaxel.models.private_location
=====================================

Classes
-------

`PrivateLocation(name: blaxel.types.Unset | str = <blaxel.types.Unset object>)`
:   Private location available for policies
    
    Attributes:
        name (Union[Unset, str]): Location name
    
    Method generated by attrs for class PrivateLocation.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `name: blaxel.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :